StateCRUD class

Constructors

StateCRUD()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createPageStateIndex(int pageIndex) → Future<void>
Create new page state index
deletePageStateIndex() → Future<void>
Delete page state index
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readPageStateIndex() → Future<int?>
Read page state index
toString() → String
A string representation of this object.
inherited
updatePageStateIndex(int pageIndex) → Future<void>
Update page state index

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

boxName → const String
key → const String