NavigatorServices class
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
buttonPosition(int buttonNumber)
→ double
-
Gives each individual button position dynamically based on their index
-
controlButtonPosition(bool previousButton)
→ double
-
Not used with current setup
Do not delete in case of future need
-
deleteState()
→ Future<void>
-
Delete nevigator state
Resets page index for return to navigator at default start index
-
dispose()
→ void
-
Discards any resources used by the object.
inherited
-
getPreviousPageIndex()
→ List<int>?
-
Gets last index for page transition animation
Index.first = previousPage Index.last = currentPage
-
lineHeight()
→ double
-
Dynamically creates line length based on lowest button
Lowest button is based on page index length
-
navigateToPage(int index)
→ void
-
Navigates directly to page index
Skips pages based on users choice of direct navigation
-
navigatorSubtitleText()
→ String
-
Positions subtitle text precisely to right of line
-
navigatorTitleBoxPosition()
→ double
-
Positions major section title to left of line
-
nextPage()
→ void
-
Handles next page logic
Causes scrolling page controller to animate to next page
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
previousPage()
→ void
-
Handles previous page logic
Causes scrolling page controller to animate to previous page
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
saveState()
→ Future<void>
-
Checks persistant storage for saved value
Overwrites if it exists and creates it if it does not
-
setallowDirectNavigation(bool parameter)
→ void
-
Set whether user can tap buttons to go directly to index
-
setPages(List<SliverChildBuilderDelegate> inputPages)
→ void
-
Sets list of pages
Builds layouts by page contents in the form of SliverChildBuilderDelegate
-
stateCheck()
→ Future<void>
-
Checks persistant storage for saved value
Loads saved value to page state if it exists
-
toString()
→ String
-
A string representation of this object.
inherited