SequentialNavigator class

Inheritance

Constructors

SequentialNavigator({Key? key, required List<SliverChildBuilderDelegate> pages, Color? footerTextColor, Color? majorSectionTextColor, Color? minorSectionTextColor, Color? backgroundColor, Color? headerBackgroundColor, Color? headerTextColor, Color? footerBackgroundColor, Color? footerIconColor, String? majorSectionText, Color? buttonBackgroundColor, Color? buttonShadowColor, Color? buttonTextColor, Color? lineColor, String? pageOneSubtitle, String? pageTwoSubtitle, String? pageThreeSubtitle, String? pageFourSubtitle, String? pageFiveSubtitle, String? pageSixSubtitle, String? pageSevenSubtitle, bool? allowDirectNavigation})
const

Properties

allowDirectNavigation → bool?
final
backgroundColor → Color?
final
buttonBackgroundColor → Color?
final
buttonShadowColor → Color?
final
buttonTextColor → Color?
final
footerBackgroundColor → Color?
final
footerIconColor → Color?
final
footerTextColor → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
headerBackgroundColor → Color?
final
headerTextColor → Color?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lineColor → Color?
final
majorSectionText → String?
final
majorSectionTextColor → Color?
final
minorSectionTextColor → Color?
final
pageFiveSubtitle → String?
final
pageFourSubtitle → String?
final
pageOneSubtitle → String?
final
pages → List<SliverChildBuilderDelegate>
final
pageSevenSubtitle → String?
final
pageSixSubtitle → String?
final
pageThreeSubtitle → String?
final
pageTwoSubtitle → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited